<?php
/*********************************************************************************
 ** The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
 *
  ********************************************************************************/
$app_strings = array (
	'Groups'=>'Grupos',
	'DocumentFolders'=>'Carpetas Documentos',
	'Currency'=>'Monedas',
	'SINGLE_Groups'=>'Grupo',
	'SINGLE_DocumentFolders'=>'Carpeta Documento',
	'SINGLE_Currency'=>'Moneda',
);

$webservice_strings = array(
	'LBL_INVALID_OLD_PASSWORD' => 'Contraseña anterior inválida.',
	'LBL_NEW_PASSWORD_MISMATCH' => "Nueva contraseña y confirmación no coinciden.",
	'LBL_DATABASE_QUERY_ERROR' => 'Error de base de datos al procesar la operación',
	'LBL_CHANGE_PASSWORD_FAILURE' => 'No se ha podido cambiar la contraseña',
);

?>
